@@ -17,7 +17,7 @@ import tiddit.tiddit_variant as tiddit_variant
 import tiddit.tiddit_contig_analysis as tiddit_contig_analysis
 
 def main():
-	version="3.4.0"
+	version="3.5.1"
 	parser = argparse.ArgumentParser("""tiddit-{}""".format(version),add_help=False)
 	parser.add_argument("--sv"	 , help="call structural variation", required=False, action="store_true")
 	parser.add_argument("--cov"        , help="generate a coverage bed file", required=False, action="store_true")
@@ -115,11 +115,8 @@ def main():
 			i+=1
 
 		prefix=args.o
-		try:
-			os.mkdir( "{}_tiddit".format(prefix) )
-			os.mkdir("{}_tiddit/clips".format(prefix) )
-		except:
-			print("Folder already exists")
+		os.mkdir(f"{prefix}_tiddit")
+		os.mkdir(f"{prefix}_tiddit/clips")
 
 		pysam.index("-c","-m","6","-@",str(args.threads),bam_file_name,"{}_tiddit/{}.csi".format(args.o,sample_id))
 
